@@ -4,18 +4,15 @@ use utf8;
 use warnings;
 use MySQL::Admin qw(init translate);
 require Exporter;
-use vars
-    qw($defaultconfig $tmp $DefaultClass @EXPORT_OK @ISA $m_sStyle $m_bMod_perl);
-@ISA                     = qw(Exporter);
-@Template::Quick::EXPORT = qw(initTemplate appendHash Template initArray);
-%Template::Quick::EXPORT_TAGS =
-    ( 'all' => [qw(initTemplate appendHash Template initArray  )] );
-$Template::Quick::VERSION = '0.55';
-$DefaultClass             = 'Template::Quick'
-    unless defined $Template::Quick::DefaultClass;
+use vars qw($defaultconfig $tmp $DefaultClass @EXPORT_OK @ISA $m_sStyle $m_bMod_perl);
+@ISA                          = qw(Exporter);
+@Template::Quick::EXPORT      = qw(initTemplate appendHash Template initArray);
+%Template::Quick::EXPORT_TAGS = ('all' => [qw(initTemplate appendHash Template initArray  )]);
+$Template::Quick::VERSION     = '0.56';
+$DefaultClass                 = 'Template::Quick' unless defined $Template::Quick::DefaultClass;
 our %tmplate;
 $m_sStyle      = 'lze';
-$m_bMod_perl   = ( $ENV{MOD_PERL} ) ? 1 : 0;
+$m_bMod_perl   = ($ENV{MOD_PERL}) ? 1 : 0;
 $defaultconfig = '%CONFIG%';
 
 =head1 NAME
@@ -69,8 +66,9 @@ see SYNOPSIS
 
 =cut
 
-sub new {
-    my ( $class, @initializer ) = @_;
+sub new
+{
+    my ($class, @initializer) = @_;
     my $self = {};
     bless $self, ref $class || $class || $DefaultClass;
     $self->initTemplate(@initializer) if (@initializer);
@@ -93,12 +91,12 @@ sub new {
 
 =cut
 
-sub initTemplate {
-    my ( $self, @p ) = getSelf(@_);
+sub initTemplate
+{
+    my ($self, @p) = getSelf(@_);
     my $hash = $p[0];
     $DefaultClass = $self;
-    my $configfile =
-        defined $hash->{config} ? $hash->{config} : $defaultconfig;
+    my $configfile = defined $hash->{config} ? $hash->{config} : $defaultconfig;
     init($configfile) unless $m_bMod_perl;
     use Fcntl qw(:flock);
     use Symbol;
@@ -109,25 +107,25 @@ sub initTemplate {
     seek $fh, 0, 0;
     my @lines = <$fh>;
     close $fh;
-    my ( $text, $o );
+    my ($text, $o);
 
     for (@lines) {
         $text .= chomp $_;
-    SWITCH: {
-            if ( $_ =~ /\[([^\/|\]|']+)\]([^\[\/\1\]]*)/ ) {
+        SWITCH: {
+            if ($_ =~ /\[([^\/|\]|']+)\]([^\[\/\1\]]*)/) {
                 $tmplate{$1} = $2;
                 $o = $1;
                 last SWITCH;
             }
-            if ( defined $o ) {
-                if ( $_ =~ /[^\[\/$o\]]/ ) {
+            if (defined $o) {
+                if ($_ =~ /[^\[\/$o\]]/) {
                     $tmplate{$o} .= $_;
                     last SWITCH;
                 }
             }
         }
     }
-    $self->initArray( $p[1] ) if ( defined $p[1] );
+    $self->initArray($p[1]) if (defined $p[1]);
 }
 
 =head2 Template()
@@ -136,8 +134,9 @@ see initTemplate
 
 =cut
 
-sub Template {
-    my ( $self, @p ) = getSelf(@_);
+sub Template
+{
+    my ($self, @p) = getSelf(@_);
     return $self->initArray(@p);
 }
 
@@ -147,13 +146,14 @@ appendHash(\%hash);
 
 =cut
 
-sub appendHash {
-    my ( $self, @p ) = getSelf(@_);
+sub appendHash
+{
+    my ($self, @p) = getSelf(@_);
     my $hash = $p[0];
-    my $text = $tmplate{ $hash->{name} };
-    foreach my $key ( keys %{$hash} ) {
-        if ( defined $text && defined $hash->{$key} ) {
-            if ( defined $key && defined $hash->{$key} ) {
+    my $text = $tmplate{$hash->{name}};
+    foreach my $key (keys %{$hash}) {
+        if (defined $text && defined $hash->{$key}) {
+            if (defined $key && defined $hash->{$key}) {
                 $text =~ s/\[($key)\/\]/$hash->{$key}/g;
                 $text =~ s/\[tr=(\w*)\/\]/translate($1)/eg;
             }
@@ -166,12 +166,13 @@ sub appendHash {
 
 =cut
 
-sub initArray {
-    my ( $self, @p ) = getSelf(@_);
+sub initArray
+{
+    my ($self, @p) = getSelf(@_);
     my $tree = $p[0];
-    $tmp = undef if ( defined $tmp );
-    for ( my $i = 0; $i < @$tree; $i++ ) {
-        $tmp .= $self->appendHash( \%{ @$tree[$i] } );
+    $tmp = undef if (defined $tmp);
+    for (my $i = 0; $i < @$tree; $i++) {
+        $tmp .= $self->appendHash(\%{@$tree[$i]});
     }
     return $tmp;
 }
@@ -180,17 +181,12 @@ sub initArray {
 
 =cut
 
-sub getSelf {
-    return @_
-        if defined( $_[0] )
-            && ( !ref( $_[0] ) )
-            && ( $_[0] eq 'Template::Quick' );
-    return ( defined( $_[0] )
-                 && ( ref( $_[0] ) eq 'Template::Quick'
-                      || UNIVERSAL::isa( $_[0], 'Template::Quick' ) )
-        )
-        ? @_
-        : ( $Template::Quick::DefaultClass->new, @_ );
+sub getSelf
+{
+    return @_ if defined($_[0]) && (!ref($_[0])) && ($_[0] eq 'Template::Quick');
+    return (defined($_[0]) && (ref($_[0]) eq 'Template::Quick' || UNIVERSAL::isa($_[0], 'Template::Quick')))
+      ? @_
+      : ($Template::Quick::DefaultClass->new, @_);
 }
 
 =head1 AUTHOR
